@@ -724,7 +724,7 @@ def influence_tables(
         export: Boolean value that controls whether an include file with 'INFLUENCE.INC' name is created. Default: False
     """
     if min(ReDs) <=1:
-        print('\n\n\n -------  ReDs must all be strictly greater than 1.0  -------\n\n\n'
+        print('\n\n\n -------  ReDs must all be strictly greater than 1.0  -------\n\n\n')
         return 
 
     # Eq 16 from SPE 81428
